NetworkHandle

Struct NetworkHandle 

pub struct NetworkHandle {
    pub(super) command_sender: UnboundedSender<NetworkCommand>,
}
A handle for interacting with the NetworkLayer.

This struct provides a thread-safe way to send commands to the NetworkLayer and receive responses.

Fields

command_sender: UnboundedSender<NetworkCommand>

Implementations

Source

impl NetworkHandle

pub async fn send_message( &self, peer_id: PeerId, message: Message, ) -> Result<()>

Sends a chat message to a peer.

Arguments
  • peer_id - The PeerId of the recipient.
  • message - The message to send.
Errors

This function will return an error if the message cannot be sent.

pub async fn send_chat_request( &self, peer_id: PeerId, request: ChatRequest, ) -> Result<()>

Sends a chat request to a peer.

This can be used for things like sending delivery confirmations or read receipts.

Arguments
  • peer_id - The PeerId of the recipient.
  • request - The chat request to send.
Errors

This function will return an error if the request cannot be sent.

pub async fn get_connected_peers(&self) -> Result<Vec<PeerId>>

Gets the list of connected peers.

Errors

This function will return an error if the list of peers cannot be retrieved.

pub async fn mailbox_put( &self, peer_id: PeerId, recipient: [u8; 32], message: EncryptedMessage, ) -> Result<bool>

Puts a message into a mailbox.

Arguments
  • peer_id - The PeerId of the mailbox node.
  • recipient - The hash of the recipient’s public key.
  • message - The encrypted message to store.
Errors

This function will return an error if the message cannot be stored.

pub async fn mailbox_fetch( &self, peer_id: PeerId, recipient: [u8; 32], limit: usize, ) -> Result<Vec<EncryptedMessage>>

Fetches messages from a mailbox.

Arguments
  • peer_id - The PeerId of the mailbox node.
  • recipient - The hash of the recipient’s public key.
  • limit - The maximum number of messages to fetch.
Errors

This function will return an error if the messages cannot be fetched.

pub async fn mailbox_ack( &self, peer_id: PeerId, recipient: [u8; 32], msg_ids: Vec<Uuid>, ) -> Result<usize>

Acknowledges the receipt of messages from a mailbox.

This will delete the acknowledged messages from the mailbox.

Arguments
  • peer_id - The PeerId of the mailbox node.
  • recipient - The hash of the recipient’s public key.
  • msg_ids - The IDs of the messages to acknowledge.
Errors

This function will return an error if the messages cannot be acknowledged.

pub async fn start_dht_provider_query(&self, key: RecordKey) -> Result<QueryId>

Starts a Kademlia DHT query to find providers for a key.

Arguments
  • key - The key to find providers for.
Errors

This function will return an error if the query cannot be started.