pub struct NetworkHandle {
pub(super) command_sender: UnboundedSender<NetworkCommand>,
}Expand description
A handle for interacting with the NetworkLayer.
This struct provides a thread-safe way to send commands to the NetworkLayer
and receive responses.
Fields
command_sender: UnboundedSender<NetworkCommand>Implementations
Sourceimpl NetworkHandle
impl NetworkHandle
Sourcepub async fn send_chat_request(
&self,
peer_id: PeerId,
request: ChatRequest,
) -> Result<()>
pub async fn send_chat_request( &self, peer_id: PeerId, request: ChatRequest, ) -> Result<()>
Sourcepub async fn get_connected_peers(&self) -> Result<Vec<PeerId>>
pub async fn get_connected_peers(&self) -> Result<Vec<PeerId>>
Gets the list of connected peers.
Errors
This function will return an error if the list of peers cannot be retrieved.
Sourcepub async fn mailbox_put(
&self,
peer_id: PeerId,
recipient: [u8; 32],
message: EncryptedMessage,
) -> Result<bool>
pub async fn mailbox_put( &self, peer_id: PeerId, recipient: [u8; 32], message: EncryptedMessage, ) -> Result<bool>
Sourcepub async fn mailbox_fetch(
&self,
peer_id: PeerId,
recipient: [u8; 32],
limit: usize,
) -> Result<Vec<EncryptedMessage>>
pub async fn mailbox_fetch( &self, peer_id: PeerId, recipient: [u8; 32], limit: usize, ) -> Result<Vec<EncryptedMessage>>
Sourcepub async fn mailbox_ack(
&self,
peer_id: PeerId,
recipient: [u8; 32],
msg_ids: Vec<Uuid>,
) -> Result<usize>
pub async fn mailbox_ack( &self, peer_id: PeerId, recipient: [u8; 32], msg_ids: Vec<Uuid>, ) -> Result<usize>
Acknowledges the receipt of messages from a mailbox.
This will delete the acknowledged messages from the mailbox.
Arguments
peer_id- ThePeerIdof the mailbox node.recipient- The hash of the recipient’s public key.msg_ids- The IDs of the messages to acknowledge.
Errors
This function will return an error if the messages cannot be acknowledged.